==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/fr_utf8/main.php <==
<?php /* French Translation by Nuno Luciano aka Gigamaster <http://xoopserver.com> */

//          index.php          //
define("_MD_PRINTER","Version Imprimable");
define("_MD_SENDSTORY","Envoyer l'article &agrave; un ami");
define("_MD_READMORE","Lire la suite...");
define("_MD_COMMENTS","0 commentaires");
define("_MD_ONECOMMENT","1 Commentaire");
define("_MD_BYTESMORE","%s octets en plus");
define("_MD_NUMCOMMENTS","%s commentaire");

//          submit.php          //
define("_MD_SUBMITNEWS","&Eacute;crire un Article");
define("_MD_TITLE","Titre");
define("_MD_TOPIC","Sujet");
define("_MD_THESCOOP","L'annonce");
define("_MD_NOTIFYPUBLISH","Notifier par e-mail lors de la publication");
define("_MD_POST","Publier");
define("_MD_GO","Envoyer");
define("_MD_THANKS","Votre Article attend l'approbation et publication officielle par l'&eacute;quipe du site. Merci de votre participation."); //submission of news article
define("_MD_THANKS_AUTOAPPROVE","Merci de votre participation.");
define("_MD_THANKS_BUT_ERROR","Merci de votre participation. Cependant, en raison d'une <span style=\"color:red\">error</span> votre Article n'a pas &eacute;t&eacute; publi&eacute;. Nous sommes d&eacute;sol&eacute; pour ce d&eacute;rangement. Merci de contacter le webmaster.");
define("_MD_USE_HTML","Activer HTML");
define("_MD_USE_SMILEY","Activer &eacute;motic&ocirc;nes");
define("_MD_USE_BR","Activer le retour &agrave; la ligne automatique");
define("_MD_USE_XCODE","Activer le code XOOPS");
define("_MD_NO_TOPICS","Il n'existe pas de Sujets.");
define('_MD_TOPIC_IMAGE','Image de la Cat&eacute;gorie'); 
define('_MD_TOPIC_DISABLE','Ne pas afficher l\'icone de la Cat&eacute;gorie'); 
define('_MD_TOPIC_LEFT','Afficher l\'icone de la Cat&eacute;gorie icon &agrave; gauche'); 
define('_MD_TOPIC_RIGHT','Afficher l\'icone de la Cat&eacute;gorie &agrave; droite'); 
define('_MD_PUBINHOME','Publier dans la page index'); 
define('_MD_PUBLISHED','Date de publication'); 
define('_MD_EXPIRED','Expir&eacute;'); 
define('_MD_SETDATETIME','D&eacute;finir la date de publication'); 
define('_MD_SETDATETIME_DESC','* Si vous ne sp&eacute;cifiez pas une date, l\'heure actuelle est est appliqu&eacute;e.'); 
define('_MD_SETEXPDATETIME','D&eacute;finir la date d\'expiration'); 
define('_MD_SETEXPDATETIME_DESC','* Si vous ne sp&eacute;cifiez pas une date, cette option reste sans effet.'); 
define('_MD_APPROVE','Approuver cet article');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Mise &agrave; jour de la base de donn&eacute;es avec succès!'); 
define('_MD_POSTEDBY','Poster'); 
define('_MD_RELATION','Autres Articles'); 
define('_MD_ADD_RELATION','Ajouter d\'autres articles'); 
define('_MD_CHECKED_AS_RELATION','Ajouter comme Autre Article');
define('_MD_DISP_BLOCK','Afficher dans un bloc'); 
define('_MD_RUSUREDEL','Voulez vous supprimer cet article ettous ses commentaires?'); 
define('_MD_EMPTYNODELETE','Impossible de supprimer.');

//          archive.php          //
define("_MD_NEWSARCHIVES","Articles Archiv&eacute;s ");
define("_MD_ARTICLES","Articles");
define("_MD_VIEWS","Lectures");
define("_MD_DATE","Date");
define("_MD_ACTIONS","Actions");
define("_MD_PRINTERFRIENDLY","Format imprimable");
define("_MD_THEREAREINTOTAL","Il y a %s article(s) au total.");
define("_MD_INTARTICLE","J'ai trouv&eacute; un Article int&eacute;ressant sur %s");
define("_MD_INTARTFOUND","Voici l'Article int&eacute;ressant que j'ai trouv&eacute; sur %s:");
define("_MD_TOPICC","Sujet :");
define("_MD_URL","URL :");
define("_MD_NOSTORY","D&eacute;sol&eacute;, l'article recherch&eacute; n'est pas disponible!");
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","Il n'existe pas d'archives.");
define("_MD_JANUARY","Janvier");
define("_MD_FEBRUARY","F&eacute;vrier");
define("_MD_MARCH","Mars");
define("_MD_APRIL","Avril");
define("_MD_MAY","Mai");
define("_MD_JUNE","Juin");
define("_MD_JULY","Juillet");
define("_MD_AUGUST","Ao&ucirc;t");
define("_MD_SEPTEMBER","Septembre");
define("_MD_OCTOBER","Octobre");
define("_MD_NOVEMBER","Novembre");
define("_MD_DECEMBER","Decembre");

//          print.php          //
define("_MD_URLFORSTORY","Le lien pour cet Article est :");
define("_MD_THISCOMESFROM","Vous pouvez lire davantage d'Articles sur %s.");

//          header.php          //
define('_MD_RSS','RSS');
define('_MD_ARCHIVES','Archive'); // ver 2.00 added

?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/fr_utf8/main.php <==
<?php /* French Translation by Nuno Luciano aka Gigamaster <http://xoopserver.com> */

//          index.php          //

// Appended by Xoops Language Checker -GIJOE- in 2009-08-26 16:24:54
define('_MD_INPUTHELPER','Input Helper ON/OFF');
define('_MD_FCKXOOPS_ONOFF','FCK Editor ON/OFF (Note: Each of editors don&#039;t share the text)');
define('_MD_ERROR_REQUIRED','{0} is a required field.');

define("_MD_PRINTER","Version Imprimable");
define("_MD_SENDSTORY","Envoyer l'article &agrave; un ami");
define("_MD_READMORE","Lire la suite...");
define("_MD_COMMENTS","0 commentaires");
define("_MD_ONECOMMENT","1 Commentaire");
define("_MD_BYTESMORE","%s octets en plus");
define("_MD_NUMCOMMENTS","%s commentaire");

//          submit.php          //
define("_MD_SUBMITNEWS","&Eacute;crire un Article");
define("_MD_TITLE","Titre");
define("_MD_TOPIC","Sujet");
define("_MD_THESCOOP","L'annonce");
define("_MD_NOTIFYPUBLISH","Notifier par e-mail lors de la publication");
define("_MD_POST","Publier");
define("_MD_GO","Envoyer");
define("_MD_THANKS","Votre Article attend l'approbation et publication officielle par l'&eacute;quipe du site. Merci de votre participation."); //submission of news article
define("_MD_THANKS_AUTOAPPROVE","Merci de votre participation.");
define("_MD_THANKS_BUT_ERROR","Merci de votre participation. Cependant, en raison d'une <span style=\"color:red\">error</span> votre Article n'a pas &eacute;t&eacute; publi&eacute;. Nous sommes d&eacute;sol&eacute; pour ce d&eacute;rangement. Merci de contacter le webmaster.");
define("_MD_USE_HTML","Activer HTML");
define("_MD_USE_SMILEY","Activer &eacute;motic&ocirc;nes");
define("_MD_USE_BR","Activer le retour &agrave; la ligne automatique");
define("_MD_USE_XCODE","Activer le code XOOPS");
define("_MD_NO_TOPICS","Il n'existe pas de Sujets.");
define('_MD_TOPIC_IMAGE','Image de la Cat&eacute;gorie'); 
define('_MD_TOPIC_DISABLE','Ne pas afficher l\'icone de la Cat&eacute;gorie'); 
define('_MD_TOPIC_LEFT','Afficher l\'icone de la Cat&eacute;gorie icon &agrave; gauche'); 
define('_MD_TOPIC_RIGHT','Afficher l\'icone de la Cat&eacute;gorie &agrave; droite'); 
define('_MD_PUBINHOME','Publier dans la page index'); 
define('_MD_PUBLISHED','Date de publication'); 
define('_MD_EXPIRED','Expir&eacute;'); 
define('_MD_SETDATETIME','D&eacute;finir la date de publication'); 
define('_MD_SETDATETIME_DESC','* Si vous ne sp&eacute;cifiez pas une date, l\'heure actuelle est est appliqu&eacute;e.'); 
define('_MD_SETEXPDATETIME','D&eacute;finir la date d\'expiration'); 
define('_MD_SETEXPDATETIME_DESC','* Si vous ne sp&eacute;cifiez pas une date, cette option reste sans effet.'); 
define('_MD_APPROVE','Approuver cet article');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Mise &agrave; jour de la base de donn&eacute;es avec succès!'); 
define('_MD_POSTEDBY','Poster'); 
define('_MD_RELATION','Autres Articles'); 
define('_MD_ADD_RELATION','Ajouter d\'autres articles'); 
define('_MD_CHECKED_AS_RELATION','Ajouter comme Autre Article');
define('_MD_DISP_BLOCK','Afficher dans un bloc'); 
define('_MD_RUSUREDEL','Voulez vous supprimer cet article ettous ses commentaires?'); 
define('_MD_EMPTYNODELETE','Impossible de supprimer.');

//          archive.php          //
define("_MD_NEWSARCHIVES","Articles Archiv&eacute;s ");
define("_MD_ARTICLES","Articles");
define("_MD_VIEWS","Lectures");
define("_MD_DATE","Date");
define("_MD_ACTIONS","Actions");
define("_MD_PRINTERFRIENDLY","Format imprimable");
define("_MD_THEREAREINTOTAL","Il y a %s article(s) au total.");
define("_MD_INTARTICLE","J'ai trouv&eacute; un Article int&eacute;ressant sur %s");
define("_MD_INTARTFOUND","Voici l'Article int&eacute;ressant que j'ai trouv&eacute; sur %s:");
define("_MD_TOPICC","Sujet :");
define("_MD_URL","URL :");
define("_MD_NOSTORY","D&eacute;sol&eacute;, l'article recherch&eacute; n'est pas disponible!");
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","Il n'existe pas d'archives.");
define("_MD_JANUARY","Janvier");
define("_MD_FEBRUARY","F&eacute;vrier");
define("_MD_MARCH","Mars");
define("_MD_APRIL","Avril");
define("_MD_MAY","Mai");
define("_MD_JUNE","Juin");
define("_MD_JULY","Juillet");
define("_MD_AUGUST","Ao&ucirc;t");
define("_MD_SEPTEMBER","Septembre");
define("_MD_OCTOBER","Octobre");
define("_MD_NOVEMBER","Novembre");
define("_MD_DECEMBER","Decembre");

//          print.php          //
define("_MD_URLFORSTORY","Le lien pour cet Article est :");
define("_MD_THISCOMESFROM","Vous pouvez lire davantage d'Articles sur %s.");

//          header.php          //
define('_MD_RSS','RSS');
define('_MD_ARCHIVES','Archive'); // ver 2.00 added

?>
